[GRASS5] G_Zero()

Brad Douglas rez at touchofmadness.com
Wed Jun 22 17:15:48 EDT 2005


Objections? :

Index: zero.c
===================================================================
RCS file: /grassrepository/grass6/lib/gis/zero.c,v
retrieving revision 2.0
diff -u -r2.0 zero.c
--- zero.c	9 Nov 2004 12:23:42 -0000	2.0
+++ zero.c	22 Jun 2005 21:11:20 -0000
@@ -1,14 +1,16 @@
 #include <string.h>
 #include "gis.h"
+
+
 /****************************************************************
  *  G_zero (buf, i)
  *     char *buf           buffer to be zeroed
  *     int i               number of bytes to be zeroed
  *
  *  Zeros out a buffer to 'i' bytes
  ****************************************************************/
 
-int G_zero ( register void *buf , register int i )
+int G_zero(void *buf , size_t i)
 {
 	memset(buf,0,i);
 
@@ -1,14 +1,16 @@
  *  G_zero (buf, i)
  *     char *buf           buffer to be zeroed
- *     int i               number of bytes to be zeroed
+ *     size_t i            number of bytes to be zeroed
  *
  *  Zeros out a buffer to 'i' bytes



-- 
Brad Douglas <rez at touchofmadness.com>




More information about the grass-dev mailing list